# Music Modelling Kit - MMK

-----

**Table of Contents**

* [Installation](#installation)
* [License](#license)

## Installation

mmk is distributed on [PyPI](https://pypi.org) as a universal
wheel and is available on Linux/macOS and Windows and supports
Python 3.7+ and PyPy.

```bash
$ pip install mmk
```

## License

mmk is distributed under the terms of the [GNU General Public License v3.0](https://choosealicense.com/licenses/gpl-3.0/)
